package com.example.demo.repository;

import com.example.demo.model.Car;
import org.springframework.data.domain.OffsetScrollPosition;
import org.springframework.data.domain.Window;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.stereotype.Repository;

@Repository
public interface CarRepository extends JpaRepository<Car, Integer> {

    /*
    The <code>findFirst3ByModelYear</code> method is a custom query method typically found in a Spring Data JPA repository interface. It serves the purpose of retrieving a window of up to three <code>Car</code> entities from a database based on the specified <code>modelYear</code> and a provided <code>OffsetScrollPosition</code>. The <code>modelYear</code> parameter acts as a filter, allowing you to narrow down the results to <code>Car</code> entities with a specific model year. The <code>OffsetScrollPosition position</code> parameter determines the starting point or scroll position for fetching the data, and its type suggests it's used for specifying an offset or the initial position when dealing with potentially large result sets. The method returns a <code>Window</code> object containing the selected <code>Car</code> entities. This approach is particularly valuable for implementing pagination or windowing in applications, as it enables the retrieval of data in manageable batches, improving performance and memory efficiency when working with extensive datasets. The <code>OffsetScrollPosition</code> parameter allows for efficient navigation through large sets of records.
     */
    Window<Car> findFirst3ByModelYear(String modelYear, OffsetScrollPosition position);
}
